==> logs-1.101.0-sources.jar: software/amazon/awscdk/services/logs/CfnDestinationProps.java <==
package software.amazon.awscdk.services.logs;

/**
 * Properties for defining a `AWS::Logs::Destination`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-28T11:07:41.991Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.logs.$Module.class, fqn = "@aws-cdk/aws-logs.CfnDestinationProps")
@software.amazon.jsii.Jsii.Proxy(CfnDestinationProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnDestinationProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Logs::Destination.DestinationName`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getDestinationName();

    /**
     * `AWS::Logs::Destination.DestinationPolicy`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getDestinationPolicy();

    /**
     * `AWS::Logs::Destination.RoleArn`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getRoleArn();

    /**
     * `AWS::Logs::Destination.TargetArn`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTargetArn();

    /**
     * @return a {@link Builder} of {@link CfnDestinationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnDestinationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnDestinationProps> {
        private java.lang.String destinationName;
        private java.lang.String destinationPolicy;
        private java.lang.String roleArn;
        private java.lang.String targetArn;

        /**
         * Sets the value of {@link CfnDestinationProps#getDestinationName}
         * @param destinationName `AWS::Logs::Destination.DestinationName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder destinationName(java.lang.String destinationName) {
            this.destinationName = destinationName;
            return this;
        }

        /**
         * Sets the value of {@link CfnDestinationProps#getDestinationPolicy}
         * @param destinationPolicy `AWS::Logs::Destination.DestinationPolicy`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder destinationPolicy(java.lang.String destinationPolicy) {
            this.destinationPolicy = destinationPolicy;
            return this;
        }

        /**
         * Sets the value of {@link CfnDestinationProps#getRoleArn}
         * @param roleArn `AWS::Logs::Destination.RoleArn`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder roleArn(java.lang.String roleArn) {
            this.roleArn = roleArn;
            return this;
        }

        /**
         * Sets the value of {@link CfnDestinationProps#getTargetArn}
         * @param targetArn `AWS::Logs::Destination.TargetArn`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetArn(java.lang.String targetArn) {
            this.targetArn = targetArn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnDestinationProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnDestinationProps build() {
            return new Jsii$Proxy(destinationName, destinationPolicy, roleArn, targetArn);
        }
    }

    /**
     * An implementation for {@link CfnDestinationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnDestinationProps {
        private final java.lang.String destinationName;
        private final java.lang.String destinationPolicy;
        private final java.lang.String roleArn;
        private final java.lang.String targetArn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.destinationName = software.amazon.jsii.Kernel.get(this, "destinationName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.destinationPolicy = software.amazon.jsii.Kernel.get(this, "destinationPolicy", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.roleArn = software.amazon.jsii.Kernel.get(this, "roleArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.targetArn = software.amazon.jsii.Kernel.get(this, "targetArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String destinationName, final java.lang.String destinationPolicy, final java.lang.String roleArn, final java.lang.String targetArn) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.destinationName = java.util.Objects.requireNonNull(destinationName, "destinationName is required");
            this.destinationPolicy = java.util.Objects.requireNonNull(destinationPolicy, "destinationPolicy is required");
            this.roleArn = java.util.Objects.requireNonNull(roleArn, "roleArn is required");
            this.targetArn = java.util.Objects.requireNonNull(targetArn, "targetArn is required");
        }

        @Override
        public final java.lang.String getDestinationName() {
            return this.destinationName;
        }

        @Override
        public final java.lang.String getDestinationPolicy() {
            return this.destinationPolicy;
        }

        @Override
        public final java.lang.String getRoleArn() {
            return this.roleArn;
        }

        @Override
        public final java.lang.String getTargetArn() {
            return this.targetArn;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("destinationName", om.valueToTree(this.getDestinationName()));
            data.set("destinationPolicy", om.valueToTree(this.getDestinationPolicy()));
            data.set("roleArn", om.valueToTree(this.getRoleArn()));
            data.set("targetArn", om.valueToTree(this.getTargetArn()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-logs.CfnDestinationProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnDestinationProps.Jsii$Proxy that = (CfnDestinationProps.Jsii$Proxy) o;

            if (!destinationName.equals(that.destinationName)) return false;
            if (!destinationPolicy.equals(that.destinationPolicy)) return false;
            if (!roleArn.equals(that.roleArn)) return false;
            return this.targetArn.equals(that.targetArn);
        }

        @Override
        public final int hashCode() {
            int result = this.destinationName.hashCode();
            result = 31 * result + (this.destinationPolicy.hashCode());
            result = 31 * result + (this.roleArn.hashCode());
            result = 31 * result + (this.targetArn.hashCode());
            return result;
        }
    }
}

==> logs-1.153.1-sources.jar: software/amazon/awscdk/services/logs/CfnDestinationProps.java <==
package software.amazon.awscdk.services.logs;

/**
 * Properties for defining a `CfnDestination`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.logs.*;
 * CfnDestinationProps cfnDestinationProps = CfnDestinationProps.builder()
 *         .destinationName("destinationName")
 *         .destinationPolicy("destinationPolicy")
 *         .roleArn("roleArn")
 *         .targetArn("targetArn")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.57.0 (build f614666)", date = "2022-04-23T01:54:29.507Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.logs.$Module.class, fqn = "@aws-cdk/aws-logs.CfnDestinationProps")
@software.amazon.jsii.Jsii.Proxy(CfnDestinationProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnDestinationProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of the destination.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getDestinationName();

    /**
     * An IAM policy document that governs which AWS accounts can create subscription filters against this destination.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getDestinationPolicy();

    /**
     * The ARN of an IAM role that permits CloudWatch Logs to send data to the specified AWS resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getRoleArn();

    /**
     * The Amazon Resource Name (ARN) of the physical target where the log events are delivered (for example, a Kinesis stream).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTargetArn();

    /**
     * @return a {@link Builder} of {@link CfnDestinationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnDestinationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnDestinationProps> {
        java.lang.String destinationName;
        java.lang.String destinationPolicy;
        java.lang.String roleArn;
        java.lang.String targetArn;

        /**
         * Sets the value of {@link CfnDestinationProps#getDestinationName}
         * @param destinationName The name of the destination. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder destinationName(java.lang.String destinationName) {
            this.destinationName = destinationName;
            return this;
        }

        /**
         * Sets the value of {@link CfnDestinationProps#getDestinationPolicy}
         * @param destinationPolicy An IAM policy document that governs which AWS accounts can create subscription filters against this destination. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder destinationPolicy(java.lang.String destinationPolicy) {
            this.destinationPolicy = destinationPolicy;
            return this;
        }

        /**
         * Sets the value of {@link CfnDestinationProps#getRoleArn}
         * @param roleArn The ARN of an IAM role that permits CloudWatch Logs to send data to the specified AWS resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder roleArn(java.lang.String roleArn) {
            this.roleArn = roleArn;
            return this;
        }

        /**
         * Sets the value of {@link CfnDestinationProps#getTargetArn}
         * @param targetArn The Amazon Resource Name (ARN) of the physical target where the log events are delivered (for example, a Kinesis stream). This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetArn(java.lang.String targetArn) {
            this.targetArn = targetArn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnDestinationProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnDestinationProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnDestinationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnDestinationProps {
        private final java.lang.String destinationName;
        private final java.lang.String destinationPolicy;
        private final java.lang.String roleArn;
        private final java.lang.String targetArn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.destinationName = software.amazon.jsii.Kernel.get(this, "destinationName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.destinationPolicy = software.amazon.jsii.Kernel.get(this, "destinationPolicy", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.roleArn = software.amazon.jsii.Kernel.get(this, "roleArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.targetArn = software.amazon.jsii.Kernel.get(this, "targetArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.destinationName = java.util.Objects.requireNonNull(builder.destinationName, "destinationName is required");
            this.destinationPolicy = java.util.Objects.requireNonNull(builder.destinationPolicy, "destinationPolicy is required");
            this.roleArn = java.util.Objects.requireNonNull(builder.roleArn, "roleArn is required");
            this.targetArn = java.util.Objects.requireNonNull(builder.targetArn, "targetArn is required");
        }

        @Override
        public final java.lang.String getDestinationName() {
            return this.destinationName;
        }

        @Override
        public final java.lang.String getDestinationPolicy() {
            return this.destinationPolicy;
        }

        @Override
        public final java.lang.String getRoleArn() {
            return this.roleArn;
        }

        @Override
        public final java.lang.String getTargetArn() {
            return this.targetArn;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("destinationName", om.valueToTree(this.getDestinationName()));
            data.set("destinationPolicy", om.valueToTree(this.getDestinationPolicy()));
            data.set("roleArn", om.valueToTree(this.getRoleArn()));
            data.set("targetArn", om.valueToTree(this.getTargetArn()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-logs.CfnDestinationProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnDestinationProps.Jsii$Proxy that = (CfnDestinationProps.Jsii$Proxy) o;

            if (!destinationName.equals(that.destinationName)) return false;
            if (!destinationPolicy.equals(that.destinationPolicy)) return false;
            if (!roleArn.equals(that.roleArn)) return false;
            return this.targetArn.equals(that.targetArn);
        }

        @Override
        public final int hashCode() {
            int result = this.destinationName.hashCode();
            result = 31 * result + (this.destinationPolicy.hashCode());
            result = 31 * result + (this.roleArn.hashCode());
            result = 31 * result + (this.targetArn.hashCode());
            return result;
        }
    }
}
